aboutsummaryrefslogtreecommitdiff
path: root/gcc/tree-ssa-copyrename.c
diff options
context:
space:
mode:
authorAlexandre Oliva <aoliva@oliva.athome.lsd.ic.unicamp.br>2007-07-09 19:24:23 +0000
committerAlexandre Oliva <aoliva@gcc.gnu.org>2007-07-09 19:24:23 +0000
commit694dd537b964f0a5869c9519f3968a6eddea827a (patch)
tree1d7b5de48965fa8fb365adadd41cba047a4aa61e /gcc/tree-ssa-copyrename.c
parent13c594155d94f64e49681064ddb1a9e4e02a6562 (diff)
downloadgcc-694dd537b964f0a5869c9519f3968a6eddea827a.zip
gcc-694dd537b964f0a5869c9519f3968a6eddea827a.tar.gz
gcc-694dd537b964f0a5869c9519f3968a6eddea827a.tar.bz2
revert: re PR debug/23551 (dwarf records for inlines appear incomplete)
Revert: 2007-07-06 Alexandre Oliva <aoliva@redhat.com> PR debug/23551 * tree-ssa-copyrename.c (copy_rename_partition_coalesce): Disregard DECL_FROM_INLINE. From-SVN: r126492
Diffstat (limited to 'gcc/tree-ssa-copyrename.c')
-rw-r--r--gcc/tree-ssa-copyrename.c16
1 files changed, 12 insertions, 4 deletions
diff --git a/gcc/tree-ssa-copyrename.c b/gcc/tree-ssa-copyrename.c
index c0945d4..812ebe1 100644
--- a/gcc/tree-ssa-copyrename.c
+++ b/gcc/tree-ssa-copyrename.c
@@ -191,12 +191,20 @@ copy_rename_partition_coalesce (var_map map, tree var1, tree var2, FILE *debug)
ign1 = TREE_CODE (root1) == VAR_DECL && DECL_IGNORED_P (root1);
ign2 = TREE_CODE (root2) == VAR_DECL && DECL_IGNORED_P (root2);
- /* Never attempt to coalesce 2 user variables. */
+ /* Never attempt to coalesce 2 user variables unless one is an inline
+ variable. */
if (!ign1 && !ign2)
{
- if (debug)
- fprintf (debug, " : 2 different USER vars. No coalesce.\n");
- return false;
+ if (DECL_FROM_INLINE (root2))
+ ign2 = true;
+ else if (DECL_FROM_INLINE (root1))
+ ign1 = true;
+ else
+ {
+ if (debug)
+ fprintf (debug, " : 2 different USER vars. No coalesce.\n");
+ return false;
+ }
}
/* Don't coalesce if there are two different memory tags. */